from setuptools import setup

setup(name='hc_probability',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['hc_probability'],
      author='Uyioghosa Nosa-Ihaza',
      author_email='ihazauyi@gmail.com',
      zip_safe=False)
